import { IResource } from 'aws-cdk-lib';
import { Metric, MetricOptions } from 'aws-cdk-lib/aws-cloudwatch';
import { Construct } from 'constructs';
import { IActiveMqBrokerConfiguration } from './activemq-broker-configuration';
import { ActiveMqBrokerEngineVersion } from './activemq-broker-engine-version';
import { BrokerDeploymentBase, BrokerDeploymentProps, IBrokerDeployment } from '../broker-deployment';
import { BrokerDeploymentMode } from '../broker-deployment-mode';
import { IActiveMqBrokerUserManagement } from './usermanagement/activemq-broker-user-management';
export interface ActiveMqCloudwatchLogsExports {
    /**
     * Export general logs to CloudWatch.
     *
     * @default - undefined; do not export general logs.
     */
    readonly general?: boolean;
    /**
     * Export audit logs to CloudWatch.
     *
     * @default - undefined; do not export audit logs.
     */
    readonly audit?: boolean;
}
export interface ActiveMqBrokerDeploymentProps extends BrokerDeploymentProps {
    /**
     * Sets the User Management option for the Amazon MQ for ActiveMQ broker
     */
    readonly userManagement: IActiveMqBrokerUserManagement;
    /**
     * Sets the version of the Amazon MQ for ActiveMQ broker engine.
     */
    readonly version: ActiveMqBrokerEngineVersion;
    /**
     * Sets the number of days to retain logs for the Amazon MQ for ActiveMQ broker.
     */
    readonly logsRetentionDays?: number;
    /**
     * Sets the CloudWatch Logs exports for the Amazon MQ for ActiveMQ broker.
     *
     * @default - undefined; No logs are exported to CloudWatch.
     */
    readonly cloudwatchLogsExports?: ActiveMqCloudwatchLogsExports;
    /**
     * Sets the configuration of the Amazon MQ for ActiveMQ broker.
     */
    readonly configuration?: IActiveMqBrokerConfiguration;
}
export interface ActiveMqBrokerDeploymentBaseProps extends ActiveMqBrokerDeploymentProps {
    readonly deploymentMode: BrokerDeploymentMode;
}
export interface IActiveMqBrokerDeployment extends IResource, IBrokerDeployment {
    metricAmqpMaximumConnections(props?: MetricOptions): Metric;
    metricBurstBalance(props?: MetricOptions): Metric;
    metricCpuCreditBalance(props?: MetricOptions): Metric;
    metricCpuUtilization(props?: MetricOptions): Metric;
    metricCurrentConnectionsCount(props?: MetricOptions): Metric;
    metricEstablishedConnectionsCount(props?: MetricOptions): Metric;
    metricHeapUsage(props?: MetricOptions): Metric;
    metricInactiveDurableTopicSubscribersCount(props?: MetricOptions): Metric;
    metricJobSchedulerStorePercentUsage(props?: MetricOptions): Metric;
    metricJournalFilesForFastRecovery(props?: MetricOptions): Metric;
    metricJournalFilesForFullRecovery(props?: MetricOptions): Metric;
    metricMqttMaximumConnections(props?: MetricOptions): Metric;
    metricNetworkConnectorConnectionCount(props?: MetricOptions): Metric;
    metricNetworkIn(props?: MetricOptions): Metric;
    metricNetworkOut(props?: MetricOptions): Metric;
    metricOpenTransactionCount(props?: MetricOptions): Metric;
    metricOpenwireMaximumConnections(props?: MetricOptions): Metric;
    metricStompMaximumConnections(props?: MetricOptions): Metric;
    metricStorePercentUsage(props?: MetricOptions): Metric;
    metricTempPercentUsage(props?: MetricOptions): Metric;
    metricTotalConsumerCount(props?: MetricOptions): Metric;
    metricTotalMessageCount(props?: MetricOptions): Metric;
    metricTotalProducerCount(props?: MetricOptions): Metric;
    metricVolumeReadOps(props?: MetricOptions): Metric;
    metricVolumeWriteOps(props?: MetricOptions): Metric;
    metricWsMaximumConnections(props?: MetricOptions): Metric;
    metricConsumerCount(props?: MetricOptions): Metric;
    metricEnqueueCount(props?: MetricOptions): Metric;
    metricEnqueueTime(props?: MetricOptions): Metric;
    metricExpiredCount(props?: MetricOptions): Metric;
    metricDispatchCount(props?: MetricOptions): Metric;
    metricDequeueCount(props?: MetricOptions): Metric;
    metricInFlightCount(props?: MetricOptions): Metric;
    metricReceiveCount(props?: MetricOptions): Metric;
    metricMemoryUsage(props?: MetricOptions): Metric;
    metricProducerCount(props?: MetricOptions): Metric;
    metricQueueSize(props?: MetricOptions): Metric;
    metricTotalEnqueueCount(props?: MetricOptions): Metric;
    metricTotalDequeueCount(props?: MetricOptions): Metric;
}
export declare abstract class ActiveMqBrokerDeploymentBase extends BrokerDeploymentBase implements IActiveMqBrokerDeployment {
    get configuration(): IActiveMqBrokerConfiguration;
    constructor(scope: Construct, id: string, props: ActiveMqBrokerDeploymentBaseProps);
    metricAmqpMaximumConnections(props?: MetricOptions): Metric;
    metricBurstBalance(props?: MetricOptions): Metric;
    metricCpuCreditBalance(props?: MetricOptions): Metric;
    metricCpuUtilization(props?: MetricOptions): Metric;
    metricCurrentConnectionsCount(props?: MetricOptions): Metric;
    metricEstablishedConnectionsCount(props?: MetricOptions): Metric;
    metricHeapUsage(props?: MetricOptions): Metric;
    metricInactiveDurableTopicSubscribersCount(props?: MetricOptions): Metric;
    metricJobSchedulerStorePercentUsage(props?: MetricOptions): Metric;
    metricJournalFilesForFastRecovery(props?: MetricOptions): Metric;
    metricJournalFilesForFullRecovery(props?: MetricOptions): Metric;
    metricMqttMaximumConnections(props?: MetricOptions): Metric;
    metricNetworkConnectorConnectionCount(props?: MetricOptions): Metric;
    metricNetworkIn(props?: MetricOptions): Metric;
    metricNetworkOut(props?: MetricOptions): Metric;
    metricOpenTransactionCount(props?: MetricOptions): Metric;
    metricOpenwireMaximumConnections(props?: MetricOptions): Metric;
    metricStompMaximumConnections(props?: MetricOptions): Metric;
    metricStorePercentUsage(props?: MetricOptions): Metric;
    metricTempPercentUsage(props?: MetricOptions): Metric;
    metricTotalConsumerCount(props?: MetricOptions): Metric;
    metricTotalMessageCount(props?: MetricOptions): Metric;
    metricTotalProducerCount(props?: MetricOptions): Metric;
    metricVolumeReadOps(props?: MetricOptions): Metric;
    metricVolumeWriteOps(props?: MetricOptions): Metric;
    metricWsMaximumConnections(props?: MetricOptions): Metric;
    metricConsumerCount(props?: MetricOptions): Metric;
    metricEnqueueCount(props?: MetricOptions): Metric;
    metricEnqueueTime(props?: MetricOptions): Metric;
    metricExpiredCount(props?: MetricOptions): Metric;
    metricDispatchCount(props?: MetricOptions): Metric;
    metricDequeueCount(props?: MetricOptions): Metric;
    metricInFlightCount(props?: MetricOptions): Metric;
    metricReceiveCount(props?: MetricOptions): Metric;
    metricMemoryUsage(props?: MetricOptions): Metric;
    metricProducerCount(props?: MetricOptions): Metric;
    metricQueueSize(props?: MetricOptions): Metric;
    metricTotalEnqueueCount(props?: MetricOptions): Metric;
    metricTotalDequeueCount(props?: MetricOptions): Metric;
}
