import { IResource, Resource } from 'aws-cdk-lib';
import { AwsCustomResource } from 'aws-cdk-lib/custom-resources';
import { Construct } from 'constructs';
import { ActiveMqAuthenticationStrategy } from './activemq/activemq-authentication-strategy';
import { BrokerEngine, IBrokerDeployment } from './broker-deployment';
import { ConfigurationAssociation } from './configuration-association';
export interface ConfigurationProps {
    readonly configurationName?: string;
    readonly description?: string;
    readonly data: string;
    readonly engine: BrokerEngine;
    readonly engineVersion?: string;
    readonly authenticationStrategy?: ActiveMqAuthenticationStrategy;
}
export interface IBrokerConfiguration extends IResource {
    readonly arn: string;
    readonly id: string;
    readonly revision: number;
}
export interface BrokerConfigurationAttributes {
    readonly id?: string;
    readonly arn?: string;
    readonly revision: number;
}
export declare abstract class BrokerConfiguration extends Resource implements IBrokerConfiguration {
    /***
     * @internal
     */
    protected static _fromAttributes(scope: Construct, logicalId: string, attrs: BrokerConfigurationAttributes): IBrokerConfiguration;
    readonly arn: string;
    readonly id: string;
    readonly revision: number;
    /** @internal */
    protected _authenticationStrategy: string | undefined;
    private isAuthenticationStrategySet;
    /***
     * @internal
     */
    protected _engineVersion: string | undefined;
    private isEngineVersionSet;
    constructor(scope: Construct, id: string, props: ConfigurationProps);
    private configureEngineVersion;
    private configureAuthenticationStrategy;
    /***
     * @internal
     */
    protected _associateWith(broker: IBrokerDeployment): ConfigurationAssociation;
    /***
     * @internal
     */
    protected _createRevisor(data: string, description?: string): AwsCustomResource;
}
